/***************************************************************************
                          job_appendnfstodatabase.h  -  description
                             -------------------
    begin                : Wed Feb 27 2002
    copyright            : (C) 2002 by Holger Sattel
    email                : hsattel@rumms.uni-mannheim.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef JOB_APPENDNFSTODATABASE_H
#define JOB_APPENDNFSTODATABASE_H

#include "prokyon.h"

#include "jobbasetagmanipulation.h"

#include "lvi_nfsexport.h"

class Job_AppendNFSToDatabase : public JobBaseTagManipulation  {
 public: 
  Job_AppendNFSToDatabase(LVI_NFSExport *_Export);

  int type() { return JOB_APPEND_NFS_TO_DATABASE; }

  void run();

  ~Job_AppendNFSToDatabase();

 private:
  LVI_NFSExport *Export;
};

#endif
